DataProvider class

Constructors

DataProvider({required List<DataRepresentation> representations, String? suggestedName})

Properties

hashCode → int
The hash code for this object.
no setterinherited
representations → List<DataRepresentation>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
suggestedName → String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
register() → FutureOr<DataProviderHandle>
Registers this source with native code. The source data will be kept alive until handle is disposed.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited