DataProviderHandle class

Constructors

DataProviderHandle(int id, DataProvider provider)

Properties

hashCode → int
The hash code for this object.
no setterinherited
id → int
final
onDispose → Listenable
no setter
provider → DataProvider
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

dispose() → Future<void>
Disposes the data source. This should not be called directly. DataSource is disposed automatically when no longer needed for clipboard or drag and drop by ClipboardWriter and DragContext.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited