DataReaderItem class

Constructors

DataReaderItem({required DataReaderItemHandle handle})

Properties

hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getAvailableFormats() → Future<List<String>>
getDataForFormat(String format) → (Future<Object?>, ReadProgress)
getSuggestedName() → Future<String?>
isSynthesized(String format) → Future<bool>
isVirtual(String format) → Future<bool>
When true the content can be received through getVirtualFileReceiver. On macOS and Windows if isVirtual is true the content can only be received through getVirtualFileReceiver - getDataForFormat will return null.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override

Static Methods

getItemInfo(Iterable<DataReaderItem> items, {Duration? timeout}) → Future<List<DataReaderItemInfo>>