DataRepresentation class sealed

Implementers

Properties

format → String
no setter
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize() → dynamic
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

lazy({required String format, required FutureOr<Object?> dataProvider()}) → DataRepresentationLazy
simple({required String format, required Object? data}) → DataRepresentationSimple
virtualFile({required String format, required VirtualFileProvider virtualFileProvider, VirtualFileStorage? storageSuggestion}) → DataRepresentationVirtualFile