DataRepresentationSimple class

Single representation of data source item. Useful when data is known upfront.

Inheritance

Properties

data → Object?
final
format → String
List of platform-specific data formats.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
serialize() → dynamic
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited