ReadProgress class abstract

Progress of a read operation.

Constructors

ReadProgress()

Properties

cancellable → ValueListenable<bool>
This may change over time, client must be prepared to handle that.
no setter
fraction → ValueListenable<double?>
Range is 0.0 to 1.0. Starts with null (indeterminate progress). Guaranteed to fire at least once on either completion or failure (with value of 1.0).
no setter
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

cancel() → void
Cancels the read operation. Does nothing if already cancelled or not cancellable.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited