VirtualFile class abstract

Constructors

VirtualFile()

Properties

fileName → String?
Returns the file name or null if not available.
no setter
hashCode → int
The hash code for this object.
no setterinherited
length → int?
Returns total length if available.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

close() → void
Closes the virtual file.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
readNext() → Future<Uint8List>
Reads next chunk of the data. Returns empty list when all data has been read.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromFileUri(Uri uri) → VirtualFile
Creates virtual file from file at specific file URI. Not supported on web.