VirtualFileReceiver class abstract

Constructors

VirtualFileReceiver()

Properties

format → String
no setter
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyVirtualFile({required String targetFolder}) → (Future<String>, ReadProgress)
Copies the virtual file to specific folder and returns the path. Not available on web.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
receiveVirtualFile() → (Future<VirtualFile>, ReadProgress)
Receives the virtual file.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited