WriteProgress class abstract

Progress of a write operation.

Constructors

WriteProgress()

Properties

hashCode → int
The hash code for this object.
no setterinherited
onCancel → Listenable
Listenable invoked when receiver cancels the write operation.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
updateProgress(double fraction) → void
Manually updates progress of a write operation. If not called, progress is determined automatically based on total size and size written.

Operators

operator ==(Object other) → bool
The equality operator.
inherited