DragContext class abstract

Constructors

DragContext()

Properties

delegate ↔ DragContextDelegate?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

cancelSession(DragSession session) → void
initialize() → Future<void>
newSession({int? pointer}) → DragSession
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
startDrag({required BuildContext buildContext, required DragSession session, required DragConfiguration configuration, required Offset position, TargetedWidgetSnapshot? combinedDragImage}) → Future<void>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

instance() → Future<DragContext>