DragSession class abstract

Represents a drag session. Allows inspecting local drag data and provides notifications about drag state changes.

Constructors

DragSession()

Properties

dragCompleted → ValueListenable<DropOperation?>
Fired on drag completion. The value will contain drop operation that the drag finished with.
no setter
dragging → ValueListenable<bool>
Whether the drag session is in progress. False before drag started and after drag completed.
no setter
dragStarted → bool
True when drag session has started.
no setter
hashCode → int
The hash code for this object.
no setterinherited
lastScreenLocation → ValueListenable<Offset?>
Updated when drag session moves. On mobile and web you will only get notified when moving over application Window. On desktop platforms the notification covers entire screen.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getLocalData() → Future<List<Object?>?>
Returns local data for each of the draggable items in current session. Will return null if drag session not local, not yet active or already completed.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited