DropContextDelegate class abstract

Constructors

DropContextDelegate()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onDropEnded(BaseDropEvent event) → Future<void>
onDropLeave(BaseDropEvent event) → Future<void>
onDropUpdate(DropEvent event) → Future<DropOperation>
onGetItemPreview(ItemPreviewRequest request) → Future<ItemPreview?>
macOS and iOS only.
onPerformDrop(DropEvent event) → Future<void>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited