ItemPreview class

Constructors

ItemPreview({required Rect destinationRect, Image? destinationImage, Duration? fadeOutDelay, Duration? fadeOutDuration})

Properties

destinationImage → Image?
Destination image to which the drag image will morph. If not provided, drag image will be used.
final
destinationRect → Rect
Destination (in global coordinates) to where the item should land.
final
fadeOutDelay → Duration?
Override fade out delay
final
fadeOutDuration → Duration?
Override fade out duration
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited