ItemPreviewRequest class

Constructors

ItemPreviewRequest({required int sessionId, required int itemId, required Size size, required Duration fadeOutDelay, required Duration fadeOutDuration})

Properties

fadeOutDelay → Duration
Default delay before the item preview starts fading out
final
fadeOutDuration → Duration
Default duration of item fade out
final
hashCode → int
The hash code for this object.
no setterinherited
itemId → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sessionId → int
final
size → Size
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

deserialize(dynamic request) → ItemPreviewRequest