HotKeyManager class abstract

Constructors

HotKeyManager()

Properties

delegate ← HotKeyManagerDelegate?
no getter
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

createHotKey(HotKeyDefinition definition) → Future<int?>
Creates HotKey for given definition. Returns null if not supported on this platform.
destroyHotKey(int handle) → Future<void>
Destroys hot key with given handle;
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

instance → HotKeyManager
no setter