KeyboardLayout class

Represents a keyboard layout. Allows converting between platform specific key codes, PhysicalKeyboardKeys and LogicalKeyboardKeys.

Constructors

KeyboardLayout(Map<int, KeyboardKey> _platformToKey, Map<int, KeyboardKey> _physicalToKey, Map<int, KeyboardKey> _logicalToKey)

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getLogicalKeyForPhysicalKey(PhysicalKeyboardKey physicalKey, {bool shift = false, bool alt = false, bool meta = false}) → LogicalKeyboardKey?
Returns the LogicalKeyboardKey for given PhysicalKeyboardKey and modifiers for this keyboard layout or null if it could not have been determined.
getPhysicalKeyForLogicalKey(LogicalKeyboardKey logicalKey) → PhysicalKeyboardKey?
Returns the PhysicalKeyboardKey for given LogicalKeyboardKey for this keyboard layout or null if it could not have been determined.
getPhysicalKeyForPlatformKeyCode(int code) → PhysicalKeyboardKey?
Returns the PhysicalKeyboardKey for platform specific key code for this keyboard layout or null if it could not have been determined.
getPlatformKeyCode(KeyboardKey key) → int?
Returns the platform specific key code for given KeyboardKey for this keyboard layout or null if the code could not have been determined.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited