KeyboardLayoutManager class abstract

Allows converting between physical and logical keys according to current keyboard layout as well as notification about keyboard layout changes.

Constructors

KeyboardLayoutManager()

Properties

currentLayout → KeyboardLayout
Returns mapping for currently active keyboard layout.
no setter
hashCode → int
The hash code for this object.
no setterinherited
onLayoutChanged → Listenable
Event fired when current system keyboard layout changes.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
supported → bool
Whether keyboard layout mapping is supported on this platform. Currently it is only supported on desktop platforms.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

instance() → Future<KeyboardLayoutManager>
Returns shared instance of KeyboardLayoutManager;