DevicePixelRatio extension

Extension on image that allows to store device pixel ratio alongside the image itself.

on

Properties

devicePixelRatio ↔ double?

Available on Image, provided by the DevicePixelRatio extension

Device pixel ratio of the image or null if not set.
getter/setter pair
pointHeight → double

Available on Image, provided by the DevicePixelRatio extension

Returns the height of image in resolution independent points.
no setter
pointSize → Size

Available on Image, provided by the DevicePixelRatio extension

no setter
pointWidth → double

Available on Image, provided by the DevicePixelRatio extension

Returns the width of image in resolution independent points.
no setter